Learn R Programming

swissMrP (version 0.62)

census: Census File, Switzerland 2000

Description

The file contains the cenus information which was retrieved from the BfS (Federal Statistical Office). It consists of three variables; age (4 groups), gender, and education (6 groups) - see details for more information.

Usage

data(census)

Arguments

Format

The format is: List of 2 Elements

$ census48.MAZH2013: Matrix 48*26 (48 ideal types, 6*4*2) and 26 cantons. The 26 columns represent the 26 cantons, the 48 rows represent all possible combinations.

group educ age gender
row 1: 1 1 1
row 2: 1 1 2
row 3: 1 2 1
row 4: 1 2 2
row 5: 1 3 1
row 6: 1 3 2
row 7: 1 4 1
row 8: 1 4 2
row 9: 2 1 1
....
row 46: 6 3 2
row 47: 6 4 1
row 48: 6 4 2

$ INFO : see census$INFO

Details

Education: (1 - if only mandatory school or NA), (2 - Apprenticeship), (3 - High School Diploma or teachers' school), (4 - Higher education, germ: hoehere Fachausbildung), (5 - higher education 2, germ: hoehere Fachschule), (6 - Federal technical Institutes or University of apllied sciences), (7 - University). Age (1: 0-34, 2: 35-49, 3: 50-64, 4: 64-). Woman (0 man, 1 woman).

References

Bundesamt fuer Statistik (BfS). 2000. Eidgenoessische Volkszaehlung 2000; Abschlussbericht zur Volkszaehlung.

Examples

Run this code
# NOT RUN {
 # How many young men with no higher education than mandatory schooling live in 
 # the cantons  ZH, BE, and LU?
 data(census)
 census$census48.MAZH2013[1:3,1]		# 1st column is ZH
# }

Run the code above in your browser using DataLab