Learn R Programming

swissMrP (version 0.62)

swissMrP-package: Multilevel Regression and Post-Stratification (MrP) for Switzerland

Description

This package provides a number of useful functions to employ MrP for small area prediction in Switzerland. Based on a hierarchical model (based itself on survey data) one can derive cantonal preference measures. The package allows to automatize the prediction and post-stratification steps. It further provides adequate print, summary, map, and plot functions for objects of its class.

Arguments

Details

Package: swissMrP
Type: Package
Version: 0.1
Date: 2018-26-05
License: GLP-2

References

Gelman, Andrew and Thomas C. Little. 1997. Poststratification Into Many Categories Using Hierarchical Logistic Regression. Survey Research 23:127-135.

Jeffrey Lax and Justin Phillips. 2009. How Should We Estimate Public Opinion in The States? American Journal of Political Science 53 (1), 107-121.

Leemann, Lucas and Fabio Wasserfallen. 2016. The Democratic Effect of Direct Democracy. American Political Science Review 110(4): 750-762.