Learn R Programming

swissMrP (version 0.62)

zip1: Shape Files for Swiss Cantons

Description

The shape files are from the Swiss government (Swiss Federal Statistics Office, 2013).

Usage

data(zip1)

Arguments

Format

@ students: shape files are slightly more involved as they are SpatialPolygonsDataFrame objects. You should most likely not have to work with the files themselves.

Details

If you are looking at this help file then chance is that something went wrong :-(

Examples

Run this code
# NOT RUN {
# A map of the 26 Swiss cantons:
plot(zip1)
# }

Run the code above in your browser using DataLab