The shape files are from the Swiss government (Swiss Federal Statistics Office, 2013).
Usage
data(zip1)
Arguments
Format
@ students: shape files are slightly more involved as they are SpatialPolygonsDataFrame objects. You should most likely not have to work with the files themselves.
Details
If you are looking at this help file then chance is that something went wrong :-(